package com.inspect.patrol.service;

import com.inspect.patrol.domain.PatrolLinkageStrategyRef;

import java.util.List;

public interface IPatrolLinkageStrategyRefService {
    PatrolLinkageStrategyRef selectPatrolLinkageStrategyRefByLinkageStrategyRefId(Long refId);

    List<PatrolLinkageStrategyRef> selectPatrolLinkageStrategyRefList(PatrolLinkageStrategyRef ref);

    int insertPatrolLinkageStrategyRef(PatrolLinkageStrategyRef ref);

    int updatePatrolLinkageStrategyRef(PatrolLinkageStrategyRef ref);

    int deletePatrolLinkageStrategyRefByLinkageStrategyRefIds(Long[] refIds);

    int deletePatrolLinkageStrategyRefByLinkageStrategyRefId(Long refId);
}
